@@ -23,6 +23,7 @@ tests_init \
 	idirafter_munge_order \
 	idirafter_munge_sysroot \
 	idirafter_ordering \
+	modversion_uninstalled \
 	pcpath \
 	virtual_variable \
 	fragment_collision \
@@ -31,8 +32,7 @@ tests_init \
 	explicit_sysroot \
 	empty_tuple \
 	solver_requires_private_debounce \
-	billion_laughs \
-	maximum_package_depth_off_by_one
+	billion_laughs
 
 #	sysroot_munge \
 
@@ -275,8 +275,8 @@ billion_laughs_body()
 		pkgconf --with-path="${selfdir}/lib1" --validate billion-laughs
 }
 
-maximum_package_depth_off_by_one_body()
+modversion_uninstalled_body()
 {
 	atf_check -o inline:"1.2.3\n" \
-		pkgconf --with-path="${selfdir}/lib1" --modversion foo bar baz
+		pkgconf --with-path="${selfdir}/lib1" --modversion omg
 }
